import _extends from "@babel/runtime/helpers/extends";
import { createVNode as _createVNode } from "vue";
import { defineComponent, h, Fragment, Text } from 'vue';
import { unified } from 'unified'; // @ts-ignore

import rehypePrism from '@mapbox/rehype-prism';
import rehypeAttrs from 'rehype-attr';
import remarkGfm from 'remark-gfm';
import rehypeRaw from 'rehype-raw';
import rehypeSlug from 'rehype-slug';
import rehypeRewrite from 'rehype-rewrite';
import rehypeAutolinkHeadings from 'rehype-autolink-headings';
import remarkParse from 'remark-parse';
import remarkRehype from 'remark-rehype';
import { VFile } from 'vfile';
import { octiconLink } from './nodes/octiconLink';
import { copyElement } from './nodes/copyElement';
import { childrenToReact } from './utils/ast-to-vue';
var markdownPreview = {
  rehypePlugins: {
    type: Object,
    default: []
  },
  remarkPlugins: {
    type: Object,
    default: []
  },
  source: {
    default: '',
    type: String
  }
};

var getCodeStr = function getCodeStr(data, code) {
  if (data === void 0) {
    data = [];
  }

  if (code === void 0) {
    code = '';
  }

  data.forEach(node => {
    if (node.type === 'text') {
      code += node.value;
    } else if (node.type === 'element' && node.children && Array.isArray(node.children)) {
      code += getCodeStr(node.children);
    }
  });
  return code;
};

export default defineComponent({
  name: 'MarkdownPreview',
  props: markdownPreview,

  setup(props, _ref) {
    var {
      slots
    } = _ref;
    var {
      remarkPlugins,
      rehypePlugins
    } = props;

    function processor() {
      return unified().use(remarkParse).use(remarkGfm).use(remarkPlugins || []).use(remarkRehype, {
        allowDangerousHtml: true
      }).use(rehypeAttrs, {
        properties: 'attr'
      }).use(rehypeRaw).use(rehypeSlug).use(rehypeAutolinkHeadings).use(rehypePrism, {
        ignoreMissing: true,
        alias: {
          markup: ['vue', 'html']
        }
      }).use(rehypeRewrite, {
        rewrite: node => {
          if (node.type == 'element' && /h(1|2|3|4|5|6)/.test(node.tagName) && node.children && Array.isArray(node.children) && node.children.length > 0) {
            var child = node.children[0];

            if (child && child.type === 'element' && child.properties) {
              child.properties = _extends({
                className: 'anchor'
              }, child.properties);
              child.children = [octiconLink()];
            }
          }

          if (node.type === 'element' && node.tagName === 'pre') {
            var code = getCodeStr(node.children);
            node.children.push(copyElement(code));
          }
        }
      }).use(rehypePlugins || []);
    }

    return () => {
      var children = slots && slots.default ? slots.default().filter(item => item.type === Text).map(item => item.children) : [];
      var file = new VFile();
      file.value = children && children.length > 0 ? children.join() : props.source;
      var prc = processor();
      var hastNode = prc.runSync(prc.parse(file), file);

      if (hastNode.type !== 'root') {
        throw new TypeError('Expected a `root` node');
      }

      var result = h(Fragment, {}, childrenToReact(hastNode.children));
      return _createVNode("div", {
        "class": "markdown-body"
      }, [result]);
    };
  }

});
//# sourceMappingURL=index.js.map